@@ -72,6 +72,9 @@ def when(obj, strict=True):
     theMock = mock_registry.mock_for(obj)
     if theMock is None:
       theMock = mock(obj, strict=strict)
+      # If we call when on something that is not TestDouble that means we're trying to stub real object,
+      # (class, module etc.). Not to be confused with generating stubs from real classes.
+      theMock.stubbing_real_object = True
 
   theMock.expect_stubbing()
   return theMock
